@@ -12,16 +12,17 @@ class BaseCategory:
         self.api = api
 
     @classmethod
-    def get_set_params(cls, params: dict, **kwargs) -> dict:
-        exclude_params = params.copy().update(params["kwargs"])
+    def get_set_params(cls, params: dict) -> dict:
+        exclude_params = params.copy()
+        exclude_params.update(params["kwargs"])
         exclude_params.pop("kwargs")
         return {
-            k if not k.endswith("_", **kwargs) else k[:-1]: v
-            for k, v in exclude_params.keys()
+            k if not k.endswith("_") else k[:-1]: v
+            for k, v in exclude_params.items()
             if k != "self" and v is not None
         }
 
     @classmethod
-    def construct_api(cls, api: "API", **kwargs) -> "BaseCategory":
+    def construct_api(cls, api: "API") -> "BaseCategory":
         cls.api = api
         return cls
